@@ -24,11 +24,27 @@ class TestQueryMonitor(unittest.TestCase):
             self.query.url(),
             "https://dune.com/queries/0?Enum=option1&Text=plain+text&Number=12&Date=2021-01-01+12%3A34%3A56",
         )
-        self.assertEqual(Query("", 0, []).url(), "https://dune.com/queries/0")
+        self.assertEqual(Query(0, "", []).url(), "https://dune.com/queries/0")
 
     def test_parameters(self):
         self.assertEqual(self.query.parameters(), self.query_params)
 
+    def test_hash(self):
+        # Same ID, different params
+        query1 = Query(query_id=0, params=[QueryParameter.text_type("Text", "word1")])
+        query2 = Query(query_id=0, params=[QueryParameter.text_type("Text", "word2")])
+        self.assertNotEqual(hash(query1), hash(query2))
+
+        # Different ID, same
+        query1 = Query(query_id=0)
+        query2 = Query(query_id=1)
+        self.assertNotEqual(hash(query1), hash(query2))
+
+        # Different ID different params
+        query1 = Query(query_id=0)
+        query2 = Query(query_id=1, params=[QueryParameter.number_type("num", 1)])
+        self.assertNotEqual(hash(query1), hash(query2))
+
 
 if __name__ == "__main__":
     unittest.main()
